@@ -8,7 +8,7 @@
 #' selectizeInput, radioButtons, dateInput, dateRangeInput,
 #' checkboxInput, checkboxGroupInput.  Buttons are not supported,
 #' meaning that you cannot use this function to reset the value of an
-#' action button back to 0.
+#' action button back to 0. You also cannot use this function on a fileInput.
 #'
 #' @param id The id of the input element to reset or the id of an HTML
 #' tag to reset all input elements inside it.
@@ -18,6 +18,8 @@
 #' in the app's ui.
 #' @examples
 #' if (interactive()) {
+#'   library(shiny)
+#'
 #'   shinyApp(
 #'     ui = fluidPage(
 #'       useShinyjs(),
@@ -53,11 +55,22 @@ reset <- function(id) {
   # get the Shiny session
   session <- getSession()
 
+  # Make sure reset works with namespaces (shiny modules)
+  nsName <- ""
+  if (inherits(session, "session_proxy")) {
+    id <- session$ns(id)
+    nsName <- session$ns("")
+  }
+
   # send a call to JavaScript to figure out what elements to reset and what
   # values to reset them to
   shinyInputId <- paste0("shinyjs-resettable-", id)
-  session$sendCustomMessage("reset", list(id = id,
-                                          shinyInputId = shinyInputId))
+  shinyInputIdJs <- shinyInputId
+  if (inherits(session, "session_proxy")) {
+    shinyInputIdJs <- session$ns(shinyInputIdJs)
+  }
+  session$sendCustomMessage("shinyjs-reset", list(id = id,
+                                          shinyInputId = shinyInputIdJs))
 
   # listen for a response from javascript
   shiny::observeEvent(session$input[[shinyInputId]], {
@@ -72,7 +85,14 @@ reset <- function(id) {
         value <- messages[[x]][['value']]
 
         updateFunc <- sprintf("update%sInput", type)
-        funcParams <- list(session, x)
+
+        # Make sure reset works with namespecing (shiny modules)
+        id <- x
+        if (substring(id, 1, nchar(nsName)) == nsName) {
+          id <- substring(id, nchar(nsName) + 1)
+        }
+
+        funcParams <- list(session, id)
 
         # checkbox values need to be manually converted to TRUE/FALSE
         if (type == "Checkbox") {
